@@ -48,8 +48,11 @@ from .vtkParallelMPI import *
 from .vtkRenderingLICOpenGL2 import *
 from .vtkRenderingParallelLIC import *
 from .vtkRenderingParallel import *
+from .vtkRenderingVRModels import *
 from .vtkRenderingMatplotlib import *
 from .vtkRenderingLabel import *
+from .vtkChartsCore import *
+from .vtkRenderingGridAxes import *
 from .vtkRenderingContextOpenGL2 import *
 from .vtkRenderingCellGrid import *
 from .vtkParallelMPI4Py import *
@@ -79,8 +82,10 @@ from .vtkIOGeometry import *
 from .vtkIOParallel import *
 from .vtkIOMPIImage import *
 from .vtkIOLAS import *
+from .vtkIOLANLX3D import *
 from .vtkIOImport import *
 from .vtkIOIOSS import *
+from .vtkIOHDF import *
 from .vtkIOH5part import *
 from .vtkIOH5Rage import *
 from .vtkIOFides import *
@@ -97,13 +102,13 @@ from .vtkInfovisCore import *
 from .vtkRenderingGL2PSOpenGL2 import *
 from .vtkIOExportGL2PS import *
 from .vtkIOEnSight import *
-from .vtkIOHDF import *
 from .vtkIOERF import *
 from .vtkIOCityGML import *
 from .vtkIOChemistry import *
 from .vtkIOCatalystConduit import *
 from .vtkIOCONVERGECFD import *
 from .vtkIOCGNSReader import *
+from .vtkIOAvmesh import *
 from .vtkIOAsynchronous import *
 from .vtkIOAMR import *
 from .vtkIOADIOS2 import *
@@ -113,7 +118,6 @@ from .vtkRenderingAnnotation import *
 from .vtkInteractionStyle import *
 from .vtkImagingHybrid import *
 from .vtkFiltersTensor import *
-from .vtkFiltersTemporal import *
 from .vtkFiltersPython import *
 from .vtkFiltersProgrammable import *
 from .vtkFiltersModeling import *
@@ -134,6 +138,7 @@ from .vtkCommonComputationalGeometry import *
 from .vtkFiltersFlowPaths import *
 from .vtkFiltersParallelFlowPaths import *
 from .vtkFiltersParallelDIY2 import *
+from .vtkFiltersTemporal import *
 from .vtkFiltersImaging import *
 from .vtkImagingGeneral import *
 from .vtkFiltersGeometryPreview import *
@@ -141,7 +146,6 @@ from .vtkFiltersGeneric import *
 from .vtkFiltersAMR import *
 from .vtkFiltersParallelMPI import *
 from .vtkDomainsChemistryOpenGL2 import *
-from .vtkChartsCore import *
 from .vtkAcceleratorsVTKmFilters import *
 from .vtkFiltersReduction import *
 
